@@ -1,9 +1,15 @@
 // js document
 
+function h(name) {
+	// converts hash value to uppercase
+	return name.toUpperCase();
+}
+
 function generate_log_fields_hash_table() {
 	
 	for (i = 0; i < _log_fields.length; i++) {
-		_log_fields[_log_fields[i].name] = _log_fields[i];
+		var s = _log_fields[i].name;
+		_log_fields[s.toUpperCase()] = _log_fields[i];
 	}
 }
 
@@ -458,7 +464,7 @@ function build_expression_text(sub_expression_type, i, expression_id) {
 	if (sub_expression_type == 'if') {
 	
 		var log_field = _if_expressions[i].field;
-		var log_field_label = _log_fields[log_field].label + ' ';
+		var log_field_label = _log_fields[h(log_field)].label + ' ';
 		
 		var operator = _if_expressions[i].operator;
 		var operator_label = _operator_labels[operator] + ' ';
@@ -531,7 +537,7 @@ function build_action_expression_item_text(expression) {
 				
 				if (is_log_field) {
 				
-					sub_text += _log_fields[literal].label;
+					sub_text += _log_fields[h(literal)].label;
 				
 				}
 				else {
@@ -546,32 +552,32 @@ function build_action_expression_item_text(expression) {
 			sub_text = '[ ' + sub_text + ' ]';
 			text = _exp_text_concatenate;
 			text = text.replace(/__PARAM__1__/, sub_text);
-			text = text.replace(/__PARAM__2__/, _log_fields[expression.log_field].label);
+			text = text.replace(/__PARAM__2__/, _log_fields[h(expression.log_field)].label);
 			break;
 			
 		case 'convert_to_lowercase' :
 		
 			text = _exp_text_convert_to_lowercase;
-			text = text.replace(/__PARAM__1__/, _log_fields[expression.log_field].label);
+			text = text.replace(/__PARAM__1__/, _log_fields[h(expression.log_field)].label);
 			break;
 			
 		case 'convert_to_uppercase' :
 		
 			text = _exp_text_convert_to_uppercase;
-			text = text.replace(/__PARAM__1__/, _log_fields[expression.log_field].label);
+			text = text.replace(/__PARAM__1__/, _log_fields[h(expression.log_field)].label);
 			break;
 
 		case 'copy' :
 		
 			text = _exp_text_copy;
-			text = text.replace(/__PARAM__1__/, _log_fields[expression.log_field].label);
-			text = text.replace(/__PARAM__2__/, _log_fields[expression.target_log_field].label);
+			text = text.replace(/__PARAM__1__/, _log_fields[h(expression.log_field)].label);
+			text = text.replace(/__PARAM__2__/, _log_fields[h(expression.target_log_field)].label);
 			break;
 		
 		case 'match_regexp_copy' :
 		
 			text = _exp_text_match_regexp_copy;
-			text = text.replace(/__PARAM__1__/, _log_fields[expression.log_field].label);
+			text = text.replace(/__PARAM__1__/, _log_fields[h(expression.log_field)].label);
 			text = text.replace(/__PARAM__2__/, expression.literal);
 			
 			var match_regexp_copy_log_fields = expression.copy;
@@ -579,7 +585,7 @@ function build_action_expression_item_text(expression) {
 			for (var i = 0; i < match_regexp_copy_log_fields.length; i++) {
 			
 				var target_log_field = match_regexp_copy_log_fields[i].log_field;
-				var target_log_field_label = _log_fields[target_log_field].label;
+				var target_log_field_label = _log_fields[h(target_log_field)].label;
 				var sub_text = _exp_text_match_regexp_copy_2;
 				sub_text = sub_text.replace(/__PARAM__3__/, '\$' + (i + 1));
 				sub_text = sub_text.replace(/__PARAM__4__/, target_log_field_label);
@@ -595,7 +601,7 @@ function build_action_expression_item_text(expression) {
 
 		case 'find_and_replace' :
 		
-			var log_field = _log_fields[expression.log_field].label;
+			var log_field = _log_fields[h(expression.log_field)].label;
 			var literal = expression.literal;
 			var literal_2 = expression.literal_2;
 			var replace_type = expression.replace_type;
@@ -629,7 +635,7 @@ function build_action_expression_item_text(expression) {
 		case 'set' :
 		
 			text = _exp_text_set;
-			text = text.replace(/__PARAM__1__/, _log_fields[expression.log_field].label);
+			text = text.replace(/__PARAM__1__/, _log_fields[h(expression.log_field)].label);
 			text = text.replace(/__PARAM__2__/, expression.literal);
 			break;
 	}
@@ -962,8 +968,8 @@ function open_if_expression_item_form(edit_existing_item, item_index) {
 		if_expression_log_field_list.options[i].selected = is_selected;
 	}
 	
-	var active_log_field_type = _log_fields[active_log_field].type;
-	var active_log_field_type_2 = _log_fields[active_log_field].type_2;
+	var active_log_field_type = _log_fields[h(active_log_field)].type;
+	var active_log_field_type_2 = _log_fields[h(active_log_field)].type_2;
 	
 	build_if_expression_operator_list(active_operator, active_log_field_type, active_log_field_type_2);
 	
@@ -1030,8 +1036,8 @@ function update_if_expression_operator_list(dat) {
 	// or vice versa then rebuild the operator list
 	
 	var active_log_field = dat.value;
-	var active_log_field_type = _log_fields[active_log_field].type;
-	var active_log_field_type_2 = _log_fields[active_log_field].type_2;
+	var active_log_field_type = _log_fields[h(active_log_field)].type;
+	var active_log_field_type_2 = _log_fields[h(active_log_field)].type_2;
 		
 	if (active_log_field_type_2 != 'date_time') {
 	
@@ -1071,7 +1077,7 @@ function process_if_expression_item_form() {
 	var log_field = log_field_list.options[log_field_list.selectedIndex].value;
 	var operator = operator_list.options[operator_list.selectedIndex].value;
 	
-	var log_field_type = _log_fields[log_field].type;
+	var log_field_type = _log_fields[h(log_field)].type;
 	
 	// check values depending on type of log field, string, int or float
 	
@@ -1541,8 +1547,8 @@ function validate_and_process_copy() {
 	
 	if (log_field != target_log_field) {
 	
-		var source_type = _log_fields[log_field].type;
-		var target_type = _log_fields[target_log_field].type;
+		var source_type = _log_fields[h(log_field)].type;
+		var target_type = _log_fields[h(target_log_field)].type;
 				
 		if ((source_type == 'string') && ((target_type == 'int') || (target_type == 'float'))) {
 			
@@ -1695,7 +1701,7 @@ function validate_and_process_set() {
 
 	var log_field = get_selected_list_item('set_log_field_list');
 	var literal = document.getElementById('set_literal_field').value;
-	var log_field_type = _log_fields[log_field].type;
+	var log_field_type = _log_fields[h(log_field)].type;
 	
 	var value_is_empty = (literal == '') ? true : false;
 	
@@ -2091,6 +2097,8 @@ function process_form() {
 			lf_comment = lf_comment.replace(/[\$]/g, '_DOL_As_Text_');
 			lf_comment = lf_comment.replace(/\n/g, '__HexEsc__0A'); // Newline
 			lf_comment = lf_comment.replace(/\r/g, ''); // Carriage return
+			
+			// alert('lf_comment: ' + lf_comment);
 						
 			var volatile_path = 'volatile.form_processing';
 			
@@ -2592,6 +2600,9 @@ function build_if_expressions_hfe() {
 		new_hfe(volatile_path + '.log_field', _if_expressions[i].field);
 		new_hfe(volatile_path + '.operator', _if_expressions[i].operator);
 		new_hfe(volatile_path + '.literal', _if_expressions[i].literal);
+		
+		// Add position node so that we can sort the node prior saving it
+		new_hfe(volatile_path + '.position', i);
 	}
 }
 
@@ -2621,6 +2632,9 @@ function build_action_expressions_hfe(sub_expression_type) {
 		var volatile_path = 'volatile.form_processing.' + sub_expression_type + '_expressions.' + i;
 		
 		new_hfe(volatile_path + '.type', action_type);
+		
+		// Add position node so that we can sort the node prior saving it
+		new_hfe(volatile_path + '.position', i);
 	
 		switch (action_type) {
 			
